summaryrefslogtreecommitdiffstats
path: root/sipgen/sip.h
diff options
context:
space:
mode:
Diffstat (limited to 'sipgen/sip.h')
-rw-r--r--sipgen/sip.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/sipgen/sip.h b/sipgen/sip.h
index 4a4910b..af3f8fa 100644
--- a/sipgen/sip.h
+++ b/sipgen/sip.h
@@ -1,18 +1,18 @@
/*
- * The main header file for SIP.
+ * The main header file for SIP-TQt.
*
* Copyright (c) 2010 Riverbank Computing Limited <info@riverbankcomputing.com>
*
- * This file is part of SIP.
+ * This file is part of SIP-TQt.
*
- * This copy of SIP is licensed for use under the terms of the SIP License
+ * This copy of SIP-TQt is licensed for use under the terms of the SIP License
* Agreement. See the file LICENSE for more details.
*
- * This copy of SIP may also used under the terms of the GNU General Public
+ * This copy of SIP-TQt may also used under the terms of the GNU General Public
* License v2 or v3 as published by the Free Software Foundation which can be
* found in the files LICENSE-GPL2 and LICENSE-GPL3 included in this package.
*
- * SIP is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
+ * SIP-TQt is supplied WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/
@@ -137,8 +137,8 @@
#define setIsHoldGILDtor(cd) ((cd)->classflags |= CLASS_DTOR_HOLD_GIL)
#define assignmentHelper(cd) ((cd)->classflags & CLASS_ASSIGN_HELPER)
#define setAssignmentHelper(cd) ((cd)->classflags |= CLASS_ASSIGN_HELPER)
-#define noPyTQt4TQMetaObject(cd) ((cd)->classflags & CLASS_NO_TQMETAOBJECT)
-#define setPyTQt4NoTQMetaObject(cd) ((cd)->classflags |= CLASS_NO_TQMETAOBJECT)
+#define noPyQt4TQMetaObject(cd) ((cd)->classflags & CLASS_NO_TQMETAOBJECT)
+#define setPyQt4NoTQMetaObject(cd) ((cd)->classflags |= CLASS_NO_TQMETAOBJECT)
#define isTemplateClass(cd) ((cd)->classflags & CLASS_IS_TEMPLATE)
#define setIsTemplateClass(cd) ((cd)->classflags |= CLASS_IS_TEMPLATE)
#define resetIsTemplateClass(cd) ((cd)->classflags &= ~CLASS_IS_TEMPLATE)
@@ -989,7 +989,7 @@ typedef struct _mroDef {
typedef struct _classDef {
int classflags; /* The class flags. */
- int pyqt4_flags; /* The PyTQt4 specific flags. */
+ int pyqt4_flags; /* The PyQt4 specific flags. */
nameDef *pyname; /* The Python name. */
ifaceFileDef *iff; /* The interface file. */
struct _classDef *ecd; /* The enclosing scope. */
@@ -1085,8 +1085,8 @@ typedef struct _parserContext {
} parserContext;
-extern char *sipVersion; /* The version of SIP. */
-extern stringList *includeDirList; /* The include directory list for SIP files. */
+extern char *sipVersion; /* The version of SIP-TQt. */
+extern stringList *includeDirList; /* The include directory list for SIP-TQt files. */
void parse(sipSpec *, FILE *, char *, stringList *, stringList *, int, int);
@@ -1140,7 +1140,7 @@ ifaceFileDef *findIfaceFile(sipSpec *pt, moduleDef *mod,
scopedNameDef *fqname, ifaceFileType iftype,
apiVersionRangeDef *api_range, argDef *ad);
int pluginPyTQt3(sipSpec *pt);
-int pluginPyTQt4(sipSpec *pt);
+int pluginPyQt4(sipSpec *pt);
void yywarning(char *);
nameDef *cacheName(sipSpec *pt, const char *name);
scopedNameDef *encodedTemplateName(templateDef *td);